/*
 * VAX-11 instruction description tables
 *
 * Format of each string is mnemonics[:ds[...]]
 * Each 'ds' is a single-character description for the kind of operand:
 *
 * A - address
 * B - byte
 * D - floating point double precision
 * F - floating point single precision
 * G - floating point double precision, extended exponent
 * H - floating point quadruple precision
 * L - long word
 * O - octaword
 * Q - quadraword
 * W - word
 * V - bit field
 * b - byte branch offset
 * r - registers mask
 * w - word branch offset
 * x - CASEB \
 * y - CASEW  | instruction variable part (e.g. LIMIT followed by OFFSETs)
 * z - CASEL /
 */

#define NULL (char *)0

char *vaxinst[256]=
{

/* 00h */

   "halt",
    "nop",
    "rei",
    "bpt",
    "ret",
    "rsb",
 "ldpctx",
 "svpctx",

/* 08h */

  "cvtps:WAWA",
  "cvtsp:WAWA",
  "index:LLLLLL",
    "crc:ALWA",
 "prober:BWA",
 "probew:BWA",
 "insque:AA",
 "remque:AL",

/* 10h */

   "bsbb:b",
    "brb:b",
   "bneq:b",
   "beql:b",
   "bgtr:b",
   "bleq:b",
    "jsb:A",
    "jmp:A",

/* 18h */

   "bgeq:b",
   "blss:b",
  "bgtru:b",
  "blequ:b",
    "bvc:b",
    "bvs:b",
    "bcc:b",
    "bcs:b",

/* 20h */

  "addp4:WAWA",
  "addp6:WAWAWA",
  "subp4:WAWA",
  "subp6:WAWAWA",
  "cvtpt:WAAWA",
   "mulp:WAWAWA",
  "cvttp:WAAWA",
   "divp:WAWAWA",

/* 28h */

  "movc3:WAA",
  "cmpc3:WAA",
  "scanc:WAAB",
  "spanc:WAAB",
  "movc5:WABWA",
  "cmpc5:WABWA",
  "movtc:WABAWA",
 "movtuc:WABAWA",

/* 30h */

   "bsbw:w",
    "brw:w",
  "cvtwl:WL",
  "cvtwb:WB",
   "movp:WAA",
  "cmpp3:WAA",
  "cvtpl:WAL",
  "cmpp4:WAWA",

/* 38h */

 "editpc:WAAA",
 "matchc:WAWA",
   "locc:BWA",
   "skpc:BWA",
 "movzwl:WL",
   "acbw:WWWw",
  "movaw:AL",
 "pushaw:A",

/* 40h */

  "addf2:FF",
  "addf3:FFF",
  "subf2:FF",
  "subf3:FFF",
  "mulf2:FF",
  "mulf3:FFF",
  "divf2:FF",
  "divf3:FFF",

/* 48h */

  "cvtfb:FB",
  "cvtfw:FW",
  "cvtfl:FL",
 "cvtrfl:FL",
  "cvtbf:BF",
  "cvtwf:WF",
  "cvtlf:LF",
   "acbf:FFFw",

/* 50h */

   "movf:FF",
   "cmpf:FF",
  "mnegf:FF",
   "tstf:F",
  "emodf:FBFLF",
  "polyf:FWA",
  "cvtfd:FD",
 NULL,

/* 58h */

  "adawi:WW",
 NULL,
 NULL,
 NULL,
 "insqhi:AA",
 "insqti:AA",
 "remqhi:AL",
 "remqti:AL",

/* 60h */

  "addd2:DD",
  "addd3:DDD",
  "subd2:DD",
  "subd3:DDD",
  "muld2:DD",
  "muld3:DDD",
  "divd2:DD",
  "divd3:DDD",

/* 68h */

  "cvtdb:DB",
  "cvtdw:DW",
  "cvtdl:DL",
 "cvtrdl:DL",
  "cvtbd:BD",
  "cvtwd:WD",
  "cvtld:LD",
   "acbd:DDDw",

/* 70h */

   "movd:DD",
   "cmpd:DD",
  "mnegd:DD",
   "tstd:D",
  "emodd:DBDLD",
  "polyd:DWA",
  "cvtdf:DF",
 NULL,

/* 78h */

   "ashl:BLL",
   "ashq:BQQ",
   "emul:LLLQ",
   "ediv:LQLL",
   "clrq:Q",
   "movq:QQ",
  "movaq:AL",
 "pushaq:A",

/* 80h */

  "addb2:BB",
  "addb3:BBB",
  "subb2:BB",
  "subb3:BBB",
  "mulb2:BB",
  "mulb3:BBB",
  "divb2:BB",
  "divb3:BBB",

/* 88h */

  "bisb2:BB",
  "bisb3:BBB",
  "bicb2:BB",
  "bicb3:BBB",
  "xorb2:BB",
  "xorb3:BBB",
  "mnegb:BB",
  "caseb:BBx",

/* 90h */

   "movb:BB",
   "cmpb:BB",
  "mcomb:BB",
   "bitb:BB",
   "clrb:B",
   "tstb:B",
   "incb:B",
   "decb:B",

/* 98h */

  "cvtbl:BL",
  "cvtbw:BW",
 "movzbl:BL",
 "movzbw:BW",
   "rotl:BLL",
   "acbb:BBBw",
  "movab:AL",
 "pushab:A",

/* A0h */

  "addw2:WW",
  "addw3:WWW",
  "subw2:WW",
  "subw3:WWW",
  "mulw2:WW",
  "mulw3:WWW",
  "divw2:WW",
  "divw3:WWW",

/* A8h */

  "bisw2:WW",
  "bisw3:WWW",
  "bicw2:WW",
  "bicw3:WWW",
  "xorw2:WW",
  "xorw3:WWW",
  "mnegw:WW",
  "casew:WWy",

/* B0h */

   "movw:WW",
   "cmpw:WW",
  "mcomw:WW",
   "bitw:WW",
   "clrw:W",
   "tstw:W",
   "incw:W",
   "decw:W",

/* B8h */

 "bispsw:W",
 "bicpsw:W",
   "popr:r",
  "pushr:r",
   "chmk:W",
   "chme:W",
   "chms:W",
   "chmu:W",

/* C0h */

  "addl2:LL",
  "addl3:LLL",
  "subl2:LL",
  "subl3:LLL",
  "mull2:LL",
  "mull3:LLL",
  "divl2:LL",
  "divl3:LLL",

/* C8h */

  "bisl2:LL",
  "bisl3:LLL",
  "bicl2:LL",
  "bicl3:LLL",
  "xorl2:LL",
  "xorl3:LLL",
  "mnegl:LL",
  "casel:LLz",

/* D0h */

   "movl:LL",
   "cmpl:LL",
  "mcoml:LL",
   "bitl:LL",
   "clrl:L",
   "tstl:L",
   "incl:L",
   "decl:L",

/* D8h */

   "adwc:LL",
   "sbwc:LL",
   "mtpr:LL",
   "mfpr:LL",
 "movpsl:L",
  "pushl:L",
  "moval:AL",
 "pushal:A",

/* E0h */

    "bbs:LVb",
    "bbc:LVb",
   "bbss:LVb",
   "bbcs:LVb",
   "bbsc:LVb",
   "bbcc:LVb",
  "bbssi:LVb",
  "bbcci:LVb",

/* E8h */

   "blbs:Lb",
   "blbc:Lb",
    "ffs:LBVL",
    "ffc:LBVL",
   "cmpv:LBVL",
  "cmpzv:LBVL",
   "extv:LBVL",
  "extzv:LBVL",

/* F0h */

   "insv:LLBV",
   "acbl:LLLw",
 "aoblss:LLb",
 "aobleq:LLb",
 "sobgeq:Lb",
 "sobgtr:Lb",
  "cvtlb:LB",
  "cvtlw:LW",

/* F8h */

   "ashp:BWABWA",
  "cvtlp:LWA",
  "callg:AA",
  "calls:LA",
    "xfc",
     NULL,
     NULL,
     NULL
};

char *vaxFD[256]=
{

/* 00h-2Fh */

 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,

/* 30h-3Fh */

 NULL,
 NULL,
  "cvtdh:DH",
  "cvtgf:GF",
 NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,

/* 40h-47h */

  "addg2:GG",
  "addg3:GGG",
  "subg2:GG",
  "subg3:GGG",
  "mulg2:GG",
  "mulg3:GGG",
  "divg2:GG",
  "divg3:GGG",

/* 48h-4Fh */

  "cvtgb:GB",
  "cvtgw:GW",
  "cvtgl:GL",
 "cvtrgl:GL",
  "cvtbg:BG",
  "cvtwg:WG",
  "cvtlg:LG",
   "acbg:GGGw",

/* 50h-57h */

   "movg:GG",
   "cmpg:GG",
  "mnegg:GG",
   "tstg:G",
  "emodg:GWGLG",
  "polyg:GWA",
  "cvtgh:GH",
 NULL,

/* 58h-5Fh */

 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,

/* 60h-67h */

  "addh2:HH",
  "addh3:HHH",
  "subh2:HH",
  "subh3:HHH",
  "mulh2:HH",
  "mulh3:HHH",
  "divh2:HH",
  "divh3:HHH",

/* 68h-6Fh */

  "cvthb:HB",
  "cvthw:HW",
  "cvthl:HL",
 "cvtrhl:HL",
  "cvtbh:BH",
  "cvtwh:WH",
  "cvtlh:LH",
   "acbh:HHHw",

/* 70h-77h */

   "movh:HH",
   "cmph:HH",
  "mnegh:HH",
   "tsth:H",
  "emodh:HWHLH",
  "polyh:HWA",
  "cvthg:HG",
 NULL,

/* 78h-7Fh */

 NULL,NULL,NULL,NULL,
   "clro:O",
   "movo:OO",
  "movao:AL",
 "pushao:A",

/* 80h-97h */

 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,

/* 98h-FFh */

  "cvtfh:FH",
  "cvtfg:FG",
           NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 NULL,NULL,NULL,NULL,NULL,NULL,
  "cvthf:HF",
  "cvthd:HD",
 NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL
};
